WlanKeyConfiguration

Struct WlanKeyConfiguration 

pub struct WlanKeyConfiguration {
    pub protection: Option<WlanProtection>,
    pub cipher_oui: Option<[u8; 3]>,
    pub cipher_type: Option<u8>,
    pub key_type: Option<KeyType>,
    pub peer_addr: Option<[u8; 6]>,
    pub key_idx: Option<u8>,
    pub key: Option<Vec<u8>>,
    pub rsc: Option<u64>,
    /* private fields */
}

Fields

protection: Option<WlanProtection>

Which path to protect: None, TX, RX, or TX and RX.

cipher_oui: Option<[u8; 3]>

IEEE Cipher suite selector. See IEEE Std 802.11-2016, 9.4.2.25.2, Table 9-131

cipher_type: Option<u8>key_type: Option<KeyType>

Whether this key is a pairwise, group or peer key.

peer_addr: Option<[u8; 6]>

The peer MAC address for pairwise and peer keys. For group keys this value is always the broadcast address.

key_idx: Option<u8>

Index for rotating keys, e.g. group keys. This value is always 0 for key types which aren’t rotating, e.g. pairwise keys.

key: Option<Vec<u8>>rsc: Option<u64>

Receive Sequence Counter for group keys only. In all other cases the RSC will be 0.