pub struct WlanRxInfo {
pub rx_flags: WlanRxInfoFlags,
pub valid_fields: WlanRxInfoValid,
pub phy: WlanPhyType,
pub data_rate: u32,
pub primary: ChannelNumber,
pub bandwidth: ChannelBandwidth,
pub vht_secondary_80_channel: ChannelNumber,
pub mcs: u8,
pub rssi_dbm: i8,
pub snr_dbh: i16,
}Fields
rx_flags: WlanRxInfoFlagsReceive flags. These represent boolean flags as opposed to enums or value-based info which are represented below. Values should be taken from the WLAN_RX_INFO_FLAGS_* enum.
valid_fields: WlanRxInfoValidBitmask indicating which of the following fields are valid in this struct. Reserved flags must be zero.
phy: WlanPhyTypeThe PHY format of the device at the time of the operation.
data_rate: u32The data rate of the device, measured in units of 0.5 Mb/s.
primary: ChannelNumberThe channel of the device at the time of the operation. This field must be included.
bandwidth: ChannelBandwidthThe bandwidth of the channel at the time of the operation.
vht_secondary_80_channel: ChannelNumberThe secondary 80 MHz channel segment, if applicable.
mcs: u8The modulation and coding scheme index of the device at the time of the operation. Depends on the PHY format and channel width.
rssi_dbm: i8Received Signal Strength Indicator.
snr_dbh: i16Signal-to-Noise Ratio, in 0.5 dB.