pub struct WlanRxInfoFlags(/* private fields */);Implementations
Sourceimpl WlanRxInfoFlags
impl WlanRxInfoFlags
Sourcepub const FCS_INVALID: WlanRxInfoFlags
pub const FCS_INVALID: WlanRxInfoFlags
The FCS for the received frame was invalid.
Sourcepub const FRAME_BODY_PADDING_4: WlanRxInfoFlags
pub const FRAME_BODY_PADDING_4: WlanRxInfoFlags
Padding was added after the MAC header to align the frame body to 4 bytes.
Sourceimpl WlanRxInfoFlags
impl WlanRxInfoFlags
Sourcepub const fn empty() -> WlanRxInfoFlags
pub const fn empty() -> WlanRxInfoFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> WlanRxInfoFlags
pub const fn all() -> WlanRxInfoFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WlanRxInfoFlags>
pub const fn from_bits(bits: u32) -> Option<WlanRxInfoFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WlanRxInfoFlags
pub const fn from_bits_truncate(bits: u32) -> WlanRxInfoFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WlanRxInfoFlags
pub const fn from_bits_retain(bits: u32) -> WlanRxInfoFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WlanRxInfoFlags>
pub fn from_name(name: &str) -> Option<WlanRxInfoFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WlanRxInfoFlags) -> bool
pub const fn intersects(&self, other: WlanRxInfoFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WlanRxInfoFlags) -> bool
pub const fn contains(&self, other: WlanRxInfoFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WlanRxInfoFlags)
pub fn insert(&mut self, other: WlanRxInfoFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WlanRxInfoFlags)
pub fn remove(&mut self, other: WlanRxInfoFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WlanRxInfoFlags)
pub fn toggle(&mut self, other: WlanRxInfoFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WlanRxInfoFlags, value: bool)
pub fn set(&mut self, other: WlanRxInfoFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
pub const fn intersection(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
pub const fn union(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
pub const fn difference(self, other: WlanRxInfoFlags) -> WlanRxInfoFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WlanRxInfoFlags,
) -> WlanRxInfoFlags
pub const fn symmetric_difference( self, other: WlanRxInfoFlags, ) -> WlanRxInfoFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WlanRxInfoFlags
pub const fn complement(self) -> WlanRxInfoFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WlanRxInfoFlags
impl WlanRxInfoFlags
Sourcepub const fn iter(&self) -> Iter<WlanRxInfoFlags> ⓘ
pub const fn iter(&self) -> Iter<WlanRxInfoFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WlanRxInfoFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<WlanRxInfoFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl WlanRxInfoFlags
impl WlanRxInfoFlags
pub fn from_bits_allow_unknown(bits: u32) -> WlanRxInfoFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32