pub struct WlanRxInfoValid(/* private fields */);Implementations
Sourceimpl WlanRxInfoValid
impl WlanRxInfoValid
pub const PHY: WlanRxInfoValid
pub const DATA_RATE: WlanRxInfoValid
pub const CHAN_WIDTH: WlanRxInfoValid
pub const MCS: WlanRxInfoValid
pub const RSSI: WlanRxInfoValid
pub const SNR: WlanRxInfoValid
Sourceimpl WlanRxInfoValid
impl WlanRxInfoValid
Sourcepub const fn empty() -> WlanRxInfoValid
pub const fn empty() -> WlanRxInfoValid
Get a flags value with all bits unset.
Sourcepub const fn all() -> WlanRxInfoValid
pub const fn all() -> WlanRxInfoValid
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WlanRxInfoValid>
pub const fn from_bits(bits: u32) -> Option<WlanRxInfoValid>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WlanRxInfoValid
pub const fn from_bits_truncate(bits: u32) -> WlanRxInfoValid
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WlanRxInfoValid
pub const fn from_bits_retain(bits: u32) -> WlanRxInfoValid
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WlanRxInfoValid>
pub fn from_name(name: &str) -> Option<WlanRxInfoValid>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WlanRxInfoValid) -> bool
pub const fn intersects(&self, other: WlanRxInfoValid) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WlanRxInfoValid) -> bool
pub const fn contains(&self, other: WlanRxInfoValid) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WlanRxInfoValid)
pub fn insert(&mut self, other: WlanRxInfoValid)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WlanRxInfoValid)
pub fn remove(&mut self, other: WlanRxInfoValid)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WlanRxInfoValid)
pub fn toggle(&mut self, other: WlanRxInfoValid)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WlanRxInfoValid, value: bool)
pub fn set(&mut self, other: WlanRxInfoValid, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WlanRxInfoValid) -> WlanRxInfoValid
pub const fn intersection(self, other: WlanRxInfoValid) -> WlanRxInfoValid
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WlanRxInfoValid) -> WlanRxInfoValid
pub const fn union(self, other: WlanRxInfoValid) -> WlanRxInfoValid
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WlanRxInfoValid) -> WlanRxInfoValid
pub const fn difference(self, other: WlanRxInfoValid) -> WlanRxInfoValid
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WlanRxInfoValid,
) -> WlanRxInfoValid
pub const fn symmetric_difference( self, other: WlanRxInfoValid, ) -> WlanRxInfoValid
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WlanRxInfoValid
pub const fn complement(self) -> WlanRxInfoValid
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WlanRxInfoValid
impl WlanRxInfoValid
Sourcepub const fn iter(&self) -> Iter<WlanRxInfoValid> ⓘ
pub const fn iter(&self) -> Iter<WlanRxInfoValid> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WlanRxInfoValid> ⓘ
pub const fn iter_names(&self) -> IterNames<WlanRxInfoValid> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl WlanRxInfoValid
impl WlanRxInfoValid
pub fn from_bits_allow_unknown(bits: u32) -> WlanRxInfoValid
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32