pub struct WlanTxInfoFlags(/* private fields */);Implementations
Sourceimpl WlanTxInfoFlags
impl WlanTxInfoFlags
Sourcepub const PROTECTED: WlanTxInfoFlags
pub const PROTECTED: WlanTxInfoFlags
Indicate this packet should be protected.
Sourcepub const FAVOR_RELIABILITY: WlanTxInfoFlags
pub const FAVOR_RELIABILITY: WlanTxInfoFlags
For rate control: indicate an important data frame, such as EAPOL, which should be sent reliably rather than fast, and is exempt from rate probing
Sourcepub const QOS: WlanTxInfoFlags
pub const QOS: WlanTxInfoFlags
Indicate that this packet should be sent out with QoS header when possible (11n+).
Sourceimpl WlanTxInfoFlags
impl WlanTxInfoFlags
Sourcepub const fn empty() -> WlanTxInfoFlags
pub const fn empty() -> WlanTxInfoFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> WlanTxInfoFlags
pub const fn all() -> WlanTxInfoFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WlanTxInfoFlags>
pub const fn from_bits(bits: u32) -> Option<WlanTxInfoFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WlanTxInfoFlags
pub const fn from_bits_truncate(bits: u32) -> WlanTxInfoFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WlanTxInfoFlags
pub const fn from_bits_retain(bits: u32) -> WlanTxInfoFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WlanTxInfoFlags>
pub fn from_name(name: &str) -> Option<WlanTxInfoFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WlanTxInfoFlags) -> bool
pub const fn intersects(&self, other: WlanTxInfoFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WlanTxInfoFlags) -> bool
pub const fn contains(&self, other: WlanTxInfoFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WlanTxInfoFlags)
pub fn insert(&mut self, other: WlanTxInfoFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WlanTxInfoFlags)
pub fn remove(&mut self, other: WlanTxInfoFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WlanTxInfoFlags)
pub fn toggle(&mut self, other: WlanTxInfoFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WlanTxInfoFlags, value: bool)
pub fn set(&mut self, other: WlanTxInfoFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
pub const fn intersection(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
pub const fn union(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
pub const fn difference(self, other: WlanTxInfoFlags) -> WlanTxInfoFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WlanTxInfoFlags,
) -> WlanTxInfoFlags
pub const fn symmetric_difference( self, other: WlanTxInfoFlags, ) -> WlanTxInfoFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WlanTxInfoFlags
pub const fn complement(self) -> WlanTxInfoFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WlanTxInfoFlags
impl WlanTxInfoFlags
Sourcepub const fn iter(&self) -> Iter<WlanTxInfoFlags> ⓘ
pub const fn iter(&self) -> Iter<WlanTxInfoFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WlanTxInfoFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<WlanTxInfoFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl WlanTxInfoFlags
impl WlanTxInfoFlags
pub fn from_bits_allow_unknown(bits: u32) -> WlanTxInfoFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32