pub struct WlanTxInfoValid(/* private fields */);Implementations
Sourceimpl WlanTxInfoValid
impl WlanTxInfoValid
pub const DATA_RATE: WlanTxInfoValid
pub const TX_VECTOR_IDX: WlanTxInfoValid
pub const PHY: WlanTxInfoValid
pub const CHANNEL_BANDWIDTH: WlanTxInfoValid
pub const MCS: WlanTxInfoValid
Sourceimpl WlanTxInfoValid
impl WlanTxInfoValid
Sourcepub const fn empty() -> WlanTxInfoValid
pub const fn empty() -> WlanTxInfoValid
Get a flags value with all bits unset.
Sourcepub const fn all() -> WlanTxInfoValid
pub const fn all() -> WlanTxInfoValid
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<WlanTxInfoValid>
pub const fn from_bits(bits: u32) -> Option<WlanTxInfoValid>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> WlanTxInfoValid
pub const fn from_bits_truncate(bits: u32) -> WlanTxInfoValid
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> WlanTxInfoValid
pub const fn from_bits_retain(bits: u32) -> WlanTxInfoValid
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WlanTxInfoValid>
pub fn from_name(name: &str) -> Option<WlanTxInfoValid>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WlanTxInfoValid) -> bool
pub const fn intersects(&self, other: WlanTxInfoValid) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WlanTxInfoValid) -> bool
pub const fn contains(&self, other: WlanTxInfoValid) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WlanTxInfoValid)
pub fn insert(&mut self, other: WlanTxInfoValid)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WlanTxInfoValid)
pub fn remove(&mut self, other: WlanTxInfoValid)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WlanTxInfoValid)
pub fn toggle(&mut self, other: WlanTxInfoValid)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WlanTxInfoValid, value: bool)
pub fn set(&mut self, other: WlanTxInfoValid, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WlanTxInfoValid) -> WlanTxInfoValid
pub const fn intersection(self, other: WlanTxInfoValid) -> WlanTxInfoValid
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WlanTxInfoValid) -> WlanTxInfoValid
pub const fn union(self, other: WlanTxInfoValid) -> WlanTxInfoValid
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WlanTxInfoValid) -> WlanTxInfoValid
pub const fn difference(self, other: WlanTxInfoValid) -> WlanTxInfoValid
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WlanTxInfoValid,
) -> WlanTxInfoValid
pub const fn symmetric_difference( self, other: WlanTxInfoValid, ) -> WlanTxInfoValid
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WlanTxInfoValid
pub const fn complement(self) -> WlanTxInfoValid
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WlanTxInfoValid
impl WlanTxInfoValid
Sourcepub const fn iter(&self) -> Iter<WlanTxInfoValid> ⓘ
pub const fn iter(&self) -> Iter<WlanTxInfoValid> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WlanTxInfoValid> ⓘ
pub const fn iter_names(&self) -> IterNames<WlanTxInfoValid> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl WlanTxInfoValid
impl WlanTxInfoValid
pub fn from_bits_allow_unknown(bits: u32) -> WlanTxInfoValid
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32