pub struct WlanSoftmacBandCapability {
pub band: Option<WlanBand>,
pub ht_caps: Option<HtCapabilities>,
pub vht_caps: Option<VhtCapabilities>,
pub basic_rates: Option<Vec<u8>>,
pub primary_channels: Option<Vec<ChannelNumber>>,
/* private fields */
}Expand description
Describes the capabilities of a SoftMAC on a particular band.
Fields
band: Option<WlanBand>Band to which the capabilities described by this datagram apply.
ht_caps: Option<HtCapabilities>Servers (i.e., drivers) should set ht_caps if the device supports HT
PHY mode or unset ht_caps if the device does not.
vht_caps: Option<VhtCapabilities>Servers (i.e., drivers) should set vht_caps if the device supports
VHT PHY mode or unset vht_caps if the device does not.
basic_rates: Option<Vec<u8>>Set of supported basic rates in units of 500 Kbit/s (as defined in IEEE Std 802.11-2016, 9.4.2.3), e.g., 0x02 represents 1 Mbps. This set represents all of the non-HT rates that the device supports for both transmitting and receiving.
primary_channels: Option<Vec<ChannelNumber>>Set of valid primary channels per regulatory information as determined by the device driver during iface creation. A primary channel refers to a channel on which APs may transmit beacon frames.
The client must use this set to determine the efficacy of subsequent requests to scan a subset of channels using the iface or to determine which primary channel to use when starting an AP.